# retailterms

A library to find retail terms in an unstructured text using NLP.

Developed by Marcel Tino (c) 2024

## Examples of How To Use the library 

You can use this to alter according to your requirements

```python
from retailterms import get_retail_entities

get_retail_entities("Footfall is lower in some stores. Shrinkage has started to increase as well")

```

Output of the library
```python
Entity Name   type
   Footfall Entity
  Shrinkage Entity

```

